@@ -19,9 +19,11 @@ except ImportError:
 from docutils import nodes
 from docutils.statemachine import ViewList
 
+from sphinx.util import force_decode
 from sphinx.util.compat import Directive
 from sphinx.util.nodes import nested_parse_with_titles
 from sphinx.util.docstrings import prepare_docstring
+from sphinx.pycode import ModuleAnalyzer
 
 from sphinxcontrib import httpdomain
 
@@ -76,10 +78,21 @@ class AutoflaskDirective(Directive):
 
     has_content = True
     required_arguments = 1
-    option_spec = {'undoc-endpoints': str,
+    option_spec = {'endpoints': str,
+                   'undoc-endpoints': str,
+                   'undoc-blueprints': str,
                    'undoc-static': str,
                    'include-empty-docstring': str}
 
+    @property
+    def endpoints(self):
+        try:
+            endpoints = re.split(r'\s*,\s*', self.options['endpoints'])
+        except KeyError:
+            # means 'endpoints' option was missing
+            return None
+        return frozenset(endpoints)
+
     @property
     def undoc_endpoints(self):
         try:
@@ -88,9 +101,26 @@ class AutoflaskDirective(Directive):
             return frozenset()
         return frozenset(endpoints)
 
+    @property
+    def undoc_blueprints(self):
+        try:
+            blueprints = re.split(r'\s*,\s*', self.options['undoc-blueprints'])
+        except KeyError:
+            return frozenset()
+        return frozenset(blueprints)
+
     def make_rst(self):
         app = import_object(self.arguments[0])
         for method, path, endpoint in get_routes(app):
+            try:
+                blueprint, endpoint_internal = endpoint.split('.')
+                if blueprint in self.undoc_blueprints:
+                    continue
+            except ValueError:
+                pass  # endpoint is not within a blueprint
+
+            if self.endpoints and endpoint not in self.endpoints:
+                continue
             if endpoint in self.undoc_endpoints:
                 continue
             try:
@@ -102,6 +132,13 @@ class AutoflaskDirective(Directive):
                 continue
             view = app.view_functions[endpoint]
             docstring = view.__doc__ or ''
+            if hasattr(view, 'view_class'):
+                meth_func = getattr(view.view_class, method.lower(), None)
+                if meth_func and meth_func.__doc__:
+                    docstring = meth_func.__doc__
+            if not isinstance(docstring, unicode):
+                analyzer = ModuleAnalyzer.for_module(view.__module__)
+                docstring = force_decode(docstring, analyzer.encoding)
             if not docstring and 'include-empty-docstring' not in self.options:
                 continue
             docstring = prepare_docstring(docstring)
