@@ -148,6 +148,8 @@ class HTTPResource(ObjectDescription):
                      names=('queryparameter', 'queryparam', 'qparam', 'query')),
         GroupedField('formparameter', label='Form Parameters',
                      names=('formparameter', 'formparam', 'fparam', 'form')),
+        GroupedField('jsonparameter', label='Json Parameters',
+                     names=('jsonparameter', 'jsonparam', 'json')),
         GroupedField('statuscode', label='Status Codes',
                      rolename='statuscode',
                      names=('statuscode', 'status', 'code'))
@@ -246,7 +248,7 @@ def http_statuscode_role(name, rawtext, text, lineno, inliner,
         try:
             code, status = re.split(r'\s', text.strip(), 1)
             code = int(code)
-        except Value:
+        except ValueError:
             msg = inliner.reporter.error(
                 'HTTP status code must be an integer (e.g. `200`) or '
                 'start with an integer (e.g. `200 OK`); %r is invalid' %
@@ -278,7 +280,7 @@ def http_method_role(name, rawtext, text, lineno, inliner,
                      options={}, content=[]):
     method = str(text).lower()
     if method not in DOCREFS:
-        msg = inliner.reporter.error('%s is not valid HTTP method' % umethod,
+        msg = inliner.reporter.error('%s is not valid HTTP method' % method,
                                      lineno=lineno)
         prb = inliner.problematic(rawtext, rawtext, msg)
         return [prb], [msg]
@@ -442,6 +444,11 @@ class HTTPLexer(RegexLexer):
         yield match.start(5), Literal, match.group(5)
         yield match.start(6), Text, match.group(6)
 
+    def continuous_header_callback(self, match):
+        yield match.start(1), Text, match.group(1)
+        yield match.start(2), Literal, match.group(2)
+        yield match.start(3), Text, match.group(3)
+
     def content_callback(self, match):
         content_type = getattr(self, 'content_type', None)
         content = match.group()
@@ -472,6 +479,7 @@ class HTTPLexer(RegexLexer):
         ],
         'headers': [
             (r'([^\s:]+)( *)(:)( *)([^\r\n]+)(\r?\n|$)', header_callback),
+            (r'([\t ]+)([^\r\n]+)(\r?\n|$)', continuous_header_callback),
             (r'\r?\n', Text, 'content')
         ],
         'content': [
